summaryrefslogtreecommitdiffstats
path: root/chrome/browser/nacl_host/nacl_process_host.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/nacl_host/nacl_process_host.h')
-rw-r--r--chrome/browser/nacl_host/nacl_process_host.h10
1 files changed, 4 insertions, 6 deletions
diff --git a/chrome/browser/nacl_host/nacl_process_host.h b/chrome/browser/nacl_host/nacl_process_host.h
index a5212de..618492a 100644
--- a/chrome/browser/nacl_host/nacl_process_host.h
+++ b/chrome/browser/nacl_host/nacl_process_host.h
@@ -29,7 +29,7 @@ class NaClProcessHost : public BrowserChildProcessHost {
// Initialize the new NaCl process, returning true on success.
bool Launch(ResourceMessageFilter* resource_message_filter,
- const int descriptor,
+ int socket_count,
IPC::Message* reply_msg);
virtual void OnMessageReceived(const IPC::Message& msg);
@@ -69,11 +69,9 @@ class NaClProcessHost : public BrowserChildProcessHost {
// The reply message to send.
IPC::Message* reply_msg_;
- // The socket pair for the NaCl process.
- nacl::Handle pair_[2];
-
- // The NaCl specific descriptor for this process.
- int descriptor_;
+ // Socket pairs for the NaCl process and renderer.
+ std::vector<nacl::Handle> sockets_for_renderer_;
+ std::vector<nacl::Handle> sockets_for_sel_ldr_;
// Windows platform flag
bool running_on_wow64_;